%global python3_pkgversion 38
%global modname dateutil

Name:           python%{python3_pkgversion}-%{modname}-epel
Version:        2.8.2
Release:        1%{?dist}
Summary:        Powerful extensions to the standard datetime module

# According to the LICENSE file:
# - BSD License applies to all code, even that also covered by ASL 2.0
# - ASL 2.0 applies to all contributions after 2017-12-01, as well as
#   all contributions that have been re-licensed.
License:        BSD or (BSD and ASL 2.0)

URL:            https://github.com/dateutil/dateutil
Source:         %{pypi_source python-%{modname}}

# Remove deprecated pytest.warns(None) from test_internals.py
#
# Fixes:
# python-dateutil fails to build with pytest 7
# https://bugzilla.redhat.com/show_bug.cgi?id=2059950
Patch1:         %{url}/commit/2bdd63158b7f981fc6d70a869680451bdfd8d848.patch

# when bootstrapping dateutil-freezegun, we cannot run tests
%bcond_with tests

BuildArch:      noarch
BuildRequires:  make
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme

%global _description \
The dateutil module provides powerful extensions to the standard datetime\
module available in Python.

%description %_description

%package -n python%{python3_pkgversion}-%{modname}
Summary:        %summary
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-rpm-macros
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-setuptools_scm
%if %{with tests}
BuildRequires:  python%{python3_pkgversion}-freezegun
BuildRequires:  python%{python3_pkgversion}-hypothesis
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-six
%endif
Requires:       tzdata

%description -n python%{python3_pkgversion}-%{modname}  %_description

%package doc
Summary: API documentation for python-dateutil
%description doc
This package contains %{summary}.

%prep
%autosetup -N -n python-%{modname}-%{version}
# the tests were moved outside of %%{modname} directory upstream after 2.8.2
# so we apply the patch with new paths from within it
pushd %{modname}/test
%patch1 -p2
popd
iconv --from=ISO-8859-1 --to=UTF-8 NEWS > NEWS.new
mv NEWS.new NEWS

%build
%py3_build
make -C docs html

%install
%py3_install

%if %{with tests}
%check
%{__python3} -m pytest -W ignore::pytest.PytestUnknownMarkWarning
%endif

%files -n python%{python3_pkgversion}-%{modname}
%license LICENSE
%doc NEWS README.rst
%{python3_sitelib}/%{modname}/
%{python3_sitelib}/*.egg-info

%files doc
%license LICENSE
%doc docs/_build/html

%changelog
* Wed Jun 29 2022 Orion Poplawski <orion@nwra.com> - 2.8.2-1
- Build for EPEL8 Python 3.8
